# Security Policy

## Supported Versions

If a vulnerability is found a new maintenance version will be release
as soon as possibe. All the previous versions should be considered unsafe.


## Reporting a Vulnerability

If you found a vulnerability, please send an email to xlcnd@outlook.com, and I will give you access
to a private part of the repository to discuss further the issue.
